<?php

namespace App\Http\Controllers;

use Srmklive\PayPal\Services\PayPal as PayPalClient;
use Illuminate\Http\Request;
use App\Models\Cart;
use App\Models\Product;
use App\Models\Order;
use App\Models\Citie;
use App\Models\State;
use App\Models\Country;
use DB;
use App\Services\UberDirectService;
use Helper;

class PaypalController extends Controller
{
    public function __construct(UberDirectService $uberDirectService)
    {
        $this->uberDirectService = $uberDirectService;
    }

    public function payment(Request $request)
    {
        $cart = Cart::where('user_id', auth()->user()->id)->where('order_id', null)->get()->toArray();
        $data = [];

        $data['items'] = array_map(function ($item) use ($cart) {
            $name = Product::where('id', $item['product_id'])->pluck('title')->first();
            return [
                'name' => $name,
                'price' => $item['price'],
                'description' => 'Thank you for using PayPal',
                'quantity' => $item['quantity']
            ];
        }, $cart);

        $data['invoice_id'] = 'ORD-' . strtoupper(uniqid());
        $data['invoice_description'] = "Order #{$data['invoice_id']} Invoice";
        $data['return_url'] = route('payment.success');
        $data['cancel_url'] = route('payment.cancel');

        $total = 0;
        if(session()->get('delivery_fee')){
            $total+=session()->get('delivery_fee');
        }
        foreach ($data['items'] as $item) {
            $total += $item['price'] * $item['quantity'];
        }

        $data['total'] = $total;
        if (session('coupon')) {
            $data['shipping_discount'] = session('coupon')['value'];
        }

        $provider = new PayPalClient;
        $provider->setApiCredentials(config('paypal'));
        $paypalToken = $provider->getAccessToken();
        $provider->setAccessToken($paypalToken);

        $response = $provider->createOrder([
            "intent" => "CAPTURE",
            "purchase_units" => [
                [
                    "amount" => [
                        "currency_code" => "USD",
                        "value" => round($data['total'], 2),
                    ],
                    "description" => $data['invoice_description'],
                    "invoice_id" => $data['invoice_id'],
                ]
            ],
            "application_context" => [
                "cancel_url" => $data['cancel_url'],
                "return_url" => $data['return_url'],
            ]
        ]);

        foreach ($response['links'] as $link) {
            if ($link['rel'] === 'approve') {
                return redirect($link['href']);
            }
        }
        return redirect()->back()->with('error', 'Something went wrong with PayPal payment');
    }

    public function cancel()
    {
        dd('Your payment is canceled.Please try again.');
    }

    public function success(Request $request)
    {
        $provider = new PayPalClient;
        $provider->setApiCredentials(config('paypal'));
        $paypalToken = $provider->getAccessToken();
        $provider->setAccessToken($paypalToken);

        $response = $provider->capturePaymentOrder($request->token);

        if ($response['status'] == 'COMPLETED') {
            return redirect()->route('payment.uber-delivery-request');
        }

        request()->session()->flash('error', 'Something went wrong please try again!!!');
        return redirect()->back();
    }

    public function uberDeliveryRequest(Request $request)
    {
        $order = Order::find(session()->get('order_id'));

        if (!$order) {
            request()->session()->flash('error', 'Order not found.');
            return redirect()->back();
        }

        $country = Country::find(session()->get('country_id'));
        $state = State::find(session()->get('state_id'));
        $city = Citie::find(session()->get('city_id'));

        $countryName = $country ? $country?->name : "";
        $stateName = $state ? $state?->name : "";
        $cityName = $city ? $city?->name : "";

        if ($order->delivery_method == "uber") {
            $deliveryData = [
                "quote_id" => $order->delivery_quote_id,
                "dropoff_name" => $order->first_name,
                "dropoff_phone_number" => $order->phone,
                "dropoff_address" => [
                    "street_address" => [$order->address1],
                    "city" => $cityName,
                    "state" => $stateName,
                    "zip_code" => $order->zip_code,
                    "country" => $countryName
                ]
            ];

            $cartProduct = Helper::getAllProductFromCart();
            $items = [];

            foreach ($cartProduct as $row) {
                $items[] = [
                    "name" => $row->product->title,
                    "quantity" => $row->quantity,
                    "price" => (int)$row->price*100,
                    "size" => $row->product->boxSize ?? "small",
                    "weight" => $row->product->weight ?? 0,
                    "dimensition" => [
                        "length" => $row->product->length ?? 0,
                        "height" => $row->product->height ?? 0,
                        "depth" => $row->product->depth ?? 0
                    ]
                ];
            }

            try {
                $delivery = $this->uberDirectService->createDelivery($deliveryData, $items);

                if ($delivery['id']) {
                    Order::where('id', $order->id)->update([
                        'delivery_id' => $delivery['id'],
                        'tracking_url' => $delivery['tracking_url']
                    ]);
                    // Cart::where('user_id', auth()->user()->id)->where('order_id', null)->update(['order_id' => $order->id]);
                }
                request()->session()->flash('success', 'You successfully paid with PayPal! Thank You');
                session()->forget('cart');
                return redirect()->route('Order.view', ['id' => $order->id]);
            } catch (\Exception $e) {
                return response()->json(['error' => $e->getMessage()], 500);
            }
        }
        session()->forget(['cart', 'coupon', 'paymentData', 'order_id', 'delivery_method', 'deliveryData']);
        return redirect()->route('home');
    }

}
