<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Services\UberDirectService;
use App\Services\GeocodingService;
use App\User;
use App\Models\Settings;
use App\Models\Country;
use App\Models\Citie;
use App\Models\State;

class UberDirectController extends Controller
{
    protected $geocodingService;
    protected $uberDirectService;

    public function __construct(GeocodingService $geocodingService, UberDirectService $uberDirectService)
    {
        $this->geocodingService = $geocodingService;
        $this->uberDirectService = $uberDirectService;
    }

    public function quoteDelivery(Request $request)
    {
        // Validate the request data
        // phone length 12 "+15555555555";
        $request->validate([
            'phone' => 'required|string',
            'country' => 'required|string',
            'city' => 'required|string',
            'state' => 'required|string',
            'zip_code' => 'required|numeric',
            'street_address' => 'required|string',
        ]);

        try {
            $dropoff_address=[
                "street_address"=>[$request->street_address],
                "city"=>$request->city,
                "state"=>$request->state,
                "zip_code"=>$request->zip_code,
                "country"=>$request->country
            ];
            // Call the Uber Direct service to create the quote
            $quote = $this->uberDirectService->quoteDelivery($dropoff_address,$request->phone);

            return response()->json($quote);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function createDelivery(Request $request)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'quote_id' => 'required|string',
            
            'dropoff_name' => 'required|string',
            'dropoff_address' => 'required|string',
            'dropoff_phone_number' => 'required|string',
            'manifest_items' => 'required|array',
            
            'dropoff_business_name' => 'required|string',
            'dropoff_latitude' => 'required|numeric',
            'dropoff_longitude' => 'required|numeric',
            'dropoff_notes' => 'nullable|string',
            'dropoff_seller_notes' => 'nullable|string',
            'deliverable_action' => 'required|string',
            'manifest_reference' => 'required|string',
            'manifest_total_value' => 'required|numeric',
            'idempotency_key' => 'required|string',
            'external_store_id' => 'required|string',
            'return_verification' => 'nullable|array',
            'external_id' => 'required|string',
        ]);
        


        // Call the Uber Direct service to create the delivery

        

        try {
            $delivery = $this->uberDirectService->createDelivery($payload);
            return response()->json($delivery);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function getDelivery($deliveryId)
    {
        try {
            $delivery = $this->uberDirectService->getDelivery($deliveryId);
            return response()->json($delivery);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }
    
    public function listDeliveries()
    {
        try {
            $deliveries = $this->uberDirectService->listDeliveries();
            return response()->json($deliveries);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function updateDelivery(Request $request, $deliveryId)
    {
        try {
            $updatedDelivery = $this->uberDirectService->updateDelivery($deliveryId, $request->all());
            return response()->json($updatedDelivery);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }



    public function cancelDelivery($deliveryId)
    {
        try {
            $this->uberDirectService->cancelDelivery($deliveryId);
            return response()->json(['message' => 'Delivery canceled successfully']);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function proofOfDelivery(Request $request, $deliveryId)
    {
        // Validate the request data
        $request->validate([
            'signature_image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        try {
            // Call the Uber Direct service to upload proof of delivery
            $signatureImage = $request->file('signature_image');
            $proofOfDelivery = $this->uberDirectService->proofOfDelivery($deliveryId, $signatureImage);

            return response()->json($proofOfDelivery);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

}
