<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Services\UberEatsService;
use App\Models\UberEatsOrder;

class UberEatsController extends Controller
{
    protected $uberEatsService;

    public function __construct(UberEatsService $uberEatsService)
    {
        $this->uberEatsService = $uberEatsService;
    }

    public function placeOrder(Request $request)
    {
        //$orderData = $request->all();
        $customer=[
            'first_name' => $order_data['first_name'],
            'last_name' => $order_data['last_name'],
            'phone' => $order_data['phone'],
            'email' => $order_data['email'],
        ];
        $payment=[
            'type' => $order_data['country']=="cod"?"cash":'prepaid', // or 'cash'
            'total_amount' => [
                'amount' => 1000, // in cents
                'currency_code' => $order_data['country']
            ]
        ];
        $order_items=[
            [
                'id' => 'item_1',
                'name' => 'Cheeseburger',
                'quantity' => 2,
                'price' => [
                    'unit_price' => [
                        'amount' => 500, // in cents
                        'currency_code' => $order_data['country']
                    ]
                ],
                'special_instructions' => 'No pickles'
            ],
            // Add more items as necessary
        ];
        $orderData = [
            'store_id' => 'your_store_id', // The ID of your store on Uber Eats
            'external_order_id' => uniqid(), // Unique ID for the order in your system
            'order_items' => $order_items,
            'customer' => $customer,
            'fulfillment' => [
                'type' => 'delivery', // or 'pickup'
                'pickup_details' => [ // Required if type is 'pickup'
                    'pickup_time' => '2024-06-01T12:30:00Z'
                ],
                'delivery_details' => [ // Required if type is 'delivery'
                    'dropoff_time' => '2024-06-01T13:00:00Z',
                    'dropoff_location' => [
                        'address' => $order_data['address1'],
                        'lat' => 37.7749,
                        'lng' => -122.4194
                    ],
                    'instructions' => 'Leave at the front door'
                ]
            ],
            'payment' => $payment
        ];
        // Validate order data here

        $response = $this->uberEatsService->placeOrder($orderData);

        UberEatsOrder::create([
            'order_id' => $response['order_id'],
            'order_data' => json_encode($response),
        ]);

        return response()->json($response);
    }

    public function trackOrder($orderId)
    {
        $response = $this->uberEatsService->trackOrder($orderId);

        return response()->json($response);
    }

    public function cancelOrder($orderId)
    {
        $response = $this->uberEatsService->cancelOrder($orderId);

        return response()->json($response);
    }
}
