<?php

namespace App\Services;

use GuzzleHttp\Client;

class UberEatsService
{
    protected $client;
    protected $baseUrl;
    protected $clientId;
    protected $clientSecret;

    public function __construct()
    {
        $this->client = new Client();
        $this->baseUrl = env('UBER_EATS_API_URL');
        $this->clientId = env('UBER_EATS_CLIENT_ID');
        $this->clientSecret = env('UBER_EATS_CLIENT_SECRET');
    }

    protected function getAuthHeaders()
    {
        return [
            'Authorization' => 'Bearer ' . $this->getAccessToken(),
            'Content-Type' => 'application/json',
        ];
    }

    protected function getAccessToken()
    {
        $response = $this->client->post($this->baseUrl . '/oauth/v2/token', [
            'form_params' => [
                'grant_type' => 'client_credentials',
                'client_id' => $this->clientId,
                'client_secret' => $this->clientSecret,
                'scope' => 'eats.order eats.write'
            ],
        ]);

        $data = json_decode($response->getBody(), true);
        return $data['access_token'];
    }

    public function placeOrder($orderData)
    {
        $response = $this->client->post($this->baseUrl . '/v1/eats/orders', [
            'headers' => $this->getAuthHeaders(),
            'json' => $orderData,
        ]);

        return json_decode($response->getBody(), true);
    }

    public function trackOrder($orderId)
    {
        $response = $this->client->get($this->baseUrl . "/v1/eats/orders/{$orderId}", [
            'headers' => $this->getAuthHeaders(),
        ]);

        return json_decode($response->getBody(), true);
    }

    public function cancelOrder($orderId)
    {
        $response = $this->client->post($this->baseUrl . "/v1/eats/orders/{$orderId}/cancel", [
            'headers' => $this->getAuthHeaders(),
        ]);

        return json_decode($response->getBody(), true);
    }
}
