@extends('frontend.layouts.master')

@section('title', 'Checkout page')

@section('main-content')

    <!-- Breadcrumbs -->
    <div class="breadcrumbs">
        <div class="container">
            <div class="row">
                <div class="col-12">
                    <div class="bread-inner">
                        <ul class="bread-list">
                            <li><a href="{{ route('home') }}">Home<i class="ti-arrow-right"></i></a></li>
                            <li class="active"><a href="javascript:void(0)">Checkout</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- End Breadcrumbs -->

    <!-- Start Checkout -->
    <section class="shop checkout section">
        <div class="container">
            <form class="form" method="POST" action="{{ route('cart.order') }}">
                @csrf
                <div class="row">
                    <input type="hidden" id="quotesId" name="quote_id" value="{{ $quote_id }}" />
                    <div class="col-lg-8 col-12">
                        <div class="checkout-form">
                            <h2>Make Your Checkout Here</h2>
                            <p>Please register in order to checkout more quickly</p>
                            <!-- Form -->
                            <div class="row">
                                <div class="col-lg-6 col-md-6 col-12">
                                    <div class="form-group">
                                        <label for="inputTitle" class="col-form-label">
                                            Name<span class="text-danger">*</span>
                                        </label>
                                        <input id="inputTitle" type="text" name="first_name" placeholder="Enter name"
                                            value="{{ $profile->name }}" class="form-control" required>
                                        @error('name')
                                            <span class="text-danger">{{ $message }}</span>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <label for="inputEmail" class="col-form-label">Email<span class="text-danger">*</span></label>
                                        <input id="inputEmail" readonly type="email" name="email"
                                            placeholder="Enter email" value="{{ $profile->email }}" class="form-control">
                                        @error('email')
                                            <span class="text-danger">{{ $message }}</span>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <label for="phone" class="col-form-label">Phone <span class="text-danger">*</span></label>
                                        <input id="phone" type="text" name="phone"
                                            placeholder="Enter Number like +15555555555 USA 11 digits" value="{{ $profile->phone }}"
                                            class="form-control" required>
                                        <span class="text-danger">Note: Enter USA number starting with + sign 11 digits</span>
                                        <br>
                                        <span id="phoneValidationMessage" style="color: red;"></span>
                                        @error('phone')
                                            <span class="text-danger">{{ $message }}</span>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <label for="street_address" class="col-form-label">Street Address<span class="text-danger">*</span></label>
                                        <textarea id="street_address" name="street_address" class="form-control"
                                            placeholder="House No, Road No, Block, City, State" required>{{ $profile->street_address }}</textarea>
                                        @error('street_address')
                                            <span class="text-danger">{{ $message }}</span>
                                        @enderror
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-6 col-12">
                                    <div class="form-group">
                                        <label for="country" class="col-form-label">Countries<span class="text-danger">*</span></label>
                                        <select id="country" name="country" class="form-control" required>
                                            <option value="">Select Country</option>
                                            @foreach ($Countries as $country)
                                                <option value="{{ $country->id }}" @selected($country->id == $profile->country)>
                                                    {{ $country->name }}</option>
                                            @endforeach
                                        </select>
                                        @error('country')
                                            <span class="text-danger">{{ $message }}</span>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <label for="state" class="col-form-label">State<span class="text-danger">*</span></label>
                                        <select id="state" name="state" class="form-control" required>
                                            @foreach ($States as $State)
                                                <option value="{{ $State->id }}" @selected($State->id == $profile->state)>
                                                    {{ $State->name }}</option>
                                            @endforeach
                                        </select>
                                        @error('state')
                                            <span class="text-danger">{{ $message }}</span>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <label for="city" class="col-form-label">City<span class="text-danger">*</span></label>
                                        <select id="city" name="city" class="form-control" required>
                                            @foreach ($Cities as $city)
                                                <option value="{{ $city->id }}" @selected($city->id == $profile->city)>
                                                    {{ $city->name }}</option>
                                            @endforeach
                                        </select>
                                        @error('City')
                                            <span class="text-danger">{{ $message }}</span>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <label for="zip_code" class="col-form-label">Zip Code<span class="text-danger">*</span></label>
                                        <input type="text" id="zip_code" name="zip_code" class="form-control"
                                            placeholder="" value="{{ $profile->zip_code }}" required>
                                        @error('zip_code')
                                            <span class='text-danger'>{{ $message }}</span>
                                        @enderror
                                    </div>
                                </div>
                            </div>
                            <!--/ End Form -->
                        </div>
                    </div>
                    <div class="col-lg-4 col-12">
                        <div class="order-details">
                            <!-- Order Widget -->
                            <div class="single-widget">
                                <h2>CART TOTALS</h2>
                                <div class="content">
                                    <ul>
                                        <li class="order_subtotal" data-price="{{ Helper::totalCartPrice() }}">Cart
                                            Subtotal<span>${{ number_format(Helper::totalCartPrice(), 2) }}</span></li>
                                        <li class="shipping">
                                            Shipping Cost
                                            <span id="shippingCost">{{ $fee }}</span>
                                            <input type="hidden" name="delivery_fee" id="delivery_fee"
                                                value="{{ $fee }}" />
                                            <div class="d-flex justify-content-center" id="loader">

                                            </div>
                                        </li>

                                        @if (session('coupon'))
                                            <li class="coupon_price" data-price="{{ session('coupon')['value'] }}">You
                                                Save<span>${{ number_format(session('coupon')['value'], 2) }}</span></li>
                                        @endif
                                        @php
                                            $total_amount = Helper::totalCartPrice() + $fee;
                                            if (session('coupon')) {
                                                $total_amount = $total_amount - session('coupon')['value'];
                                            }
                                        @endphp
                                        @if (session('coupon'))
                                            <li class="last" id="order_total_price">
                                                Total<span>${{ number_format($total_amount, 2) }}</span></li>
                                        @else
                                            <li class="last" id="order_total_price">
                                                Total<span>${{ number_format($total_amount, 2) }}</span></li>
                                        @endif
                                    </ul>
                                </div>
                            </div>
                            <!--/ End Order Widget -->

                            <!-- Order Widget -->
                            <div class="single-widget">
                                <h2>Delivery</h2>
                                <div class="content">
                                    <div class="checkbox">
                                        <form-group>
                                            <input name="delivery_method" type="radio" value="uber"
                                                @checked(true)> <label>Uber</label>
                                            <h6 class="text-danger" id="submitMessage">
                                                {{ $fee == 0 ? 'Unable to Deliver in this area! Please type appropriate address.' : '' }}
                                            </h6>
                                        </form-group>
                                    </div>
                                </div>
                            </div>
                            <!--/ End Order Widget -->

                            <!-- Order Widget -->
                            <div class="single-widget">
                                <h2>Payments</h2>
                                <div class="content">
                                    <div class="checkbox">
                                        {{-- <label class="checkbox-inline" for="1"><input name="updates" id="1" type="checkbox"> Check Payments</label> --}}
                                        <form-group>
                                            {{-- <input name="payment_method"  type="radio" value="cod"> <label> Cash On Delivery</label><br> --}}
                                            <input name="payment_method" type="radio" value="paypal"
                                                @checked(true)> <label> PayPal</label>
                                        </form-group>

                                    </div>
                                </div>
                            </div>
                            <!--/ End Order Widget -->
                            <!-- Payment Method Widget -->
                            <div class="single-widget payement">
                                <div class="content">
                                    <img src="{{ 'backend/img/payment-method.png' }}" alt="#">
                                </div>
                            </div>
                            <!--/ End Payment Method Widget -->
                            <!-- Button Widget -->
                            <div class="single-widget get-button">
                                <div class="content">
                                    <div class="button">
                                        <button type="submit" class="btn" id="submitBtn"
                                            {{ $fee == 0 ? 'disabled' : '' }}>proceed to checkout
                                        </button>
                                    </div>
                                </div>
                            </div>
                            <!--/ End Button Widget -->
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </section>
    <!--/ End Checkout -->

    <!-- Start Shop Services Area  -->
    <section class="shop-services section home">
        <div class="container">
            <div class="row">
                <div class="col-lg-3 col-md-6 col-12">
                    <!-- Start Single Service -->
                    <div class="single-service">
                        <i class="ti-rocket"></i>
                        <h4>Free shiping</h4>
                        <p>Orders over $100</p>
                    </div>
                    <!-- End Single Service -->
                </div>
                <div class="col-lg-3 col-md-6 col-12">
                    <!-- Start Single Service -->
                    <div class="single-service">
                        <i class="ti-reload"></i>
                        <h4>Free Return</h4>
                        <p>Within 30 days returns</p>
                    </div>
                    <!-- End Single Service -->
                </div>
                <div class="col-lg-3 col-md-6 col-12">
                    <!-- Start Single Service -->
                    <div class="single-service">
                        <i class="ti-lock"></i>
                        <h4>Sucure Payment</h4>
                        <p>100% secure payment</p>
                    </div>
                    <!-- End Single Service -->
                </div>
                <div class="col-lg-3 col-md-6 col-12">
                    <!-- Start Single Service -->
                    <div class="single-service">
                        <i class="ti-tag"></i>
                        <h4>Best Peice</h4>
                        <p>Guaranteed price</p>
                    </div>
                    <!-- End Single Service -->
                </div>
            </div>
        </div>
    </section>
    <!-- End Shop Services -->

    <!-- Start Shop Newsletter  -->
    <section class="shop-newsletter section">
        <div class="container">
            <div class="inner-top">
                <div class="row">
                    <div class="col-lg-8 offset-lg-2 col-12">
                        <!-- Start Newsletter Inner -->
                        <div class="inner">
                            <h4>Newsletter</h4>
                            <p> Subscribe to our newsletter and get <span>10%</span> off your first purchase</p>
                            <form action="mail/mail.php" method="get" target="_blank" class="newsletter-inner">
                                <input name="EMAIL" placeholder="Your email address" required="" type="email">
                                <button class="btn">Subscribe</button>
                            </form>
                        </div>
                        <!-- End Newsletter Inner -->
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End Shop Newsletter -->
@endsection
@push('styles')
    <style>
        li.shipping {
            display: inline-flex;
            width: 100%;
            font-size: 14px;
        }

        li.shipping .input-group-icon {
            width: 100%;
            margin-left: 10px;
        }

        .input-group-icon .icon {
            position: absolute;
            left: 20px;
            top: 0;
            line-height: 40px;
            z-index: 3;
        }

        .form-select {
            height: 30px;
            width: 100%;
        }

        .form-select {
            border: none;
            border-radius: 0px;
            height: 40px;
            background: #f6f6f6 !important;
            padding-left: 45px;
            padding-right: 40px;
            width: 100%;
        }

        .list li {
            margin-bottom: 0 !important;
        }

        .list li:hover {
            background: #F7941D !important;
            color: white !important;
        }
    </style>
@endpush
@push('scripts')
    <script>
        $(document).ready(function() {
            function showMe(box) {
                var checkbox = document.getElementById('shipping').style.display;
                var vis = 'none';
                if (checkbox == "none") {
                    vis = 'block';
                }
                if (checkbox == "block") {
                    vis = "none";
                }
                document.getElementById(box).style.display = vis;
            }

            $('form input, form textarea').keydown(function(e) {
                if (e.keyCode === 13) {
                    e.preventDefault();
                    return false;
                }
            });

            //phone number validation
            function validatePhoneNumber() {
                const regex = /^\+[0-9]{11}$/;
                const value = $('#phone').val();
                if (regex.test(value)) {
                    $('#phoneValidationMessage').text('');
                    $("#submitBtn").removeAttr("disabled");
                    checkAddress();
                } else {
                    $("#submitBtn").attr("disabled", true);
                    $('#phoneValidationMessage').text('Invalid phone number. Enter USA number starting with + sign 11 digits.');
                    checkAddress();
                }
            }

            $(document).ready(function() {
                validatePhoneNumber();
                $('#phone').on('keyup', function() {
                    validatePhoneNumber();
                });
            });

            // address fileds
            $('select').niceSelect('destroy');
            $('#country').change(function() {
                GetStates($(this).val());
                clearQuotes();
                $('#city').html('<option value="">Select City</option>');
                $("#street_address").val("");
                $("#zip_code").val("");
                checkAddress();
            });

            $('#state').change(function() {
                GetCity($(this).val());
                clearQuotes();
                $("#street_address").val("");
                $("#zip_code").val("");
                checkAddress();
            });

            $('#city').change(function() {
                clearQuotes();
                checkAddress();
                $("#street_address").val("");
                $("#zip_code").val("");
            })

            $('#street_address, #zip_code').blur(function() {
                clearQuotes();
                checkAddress();
            })
        });

        function GetStates(countryId, selected = null) {
            if (countryId) {
                $.ajax({
                    url: `/countries/${countryId}/states`,
                    type: 'GET',
                    dataType: 'json',
                    success: (data) => {
                        $('#state').empty().append('<option value="">Select State</option>');
                        let states = data.map(x =>
                                `<option value="${x?.id}" ${x?.id==selected?"selected":""}>${x?.name}</option>`)
                            .join("");
                        $('#state').append(states);
                    }
                });
            } else {
                $('#state').empty();
                $('#state').append('<option value="">Select State</option>');
            }
        }

        function GetCity(stateId, selected = null) {
            if (stateId) {
                $.ajax({
                    url: `/states/${stateId}/cities`,
                    type: 'GET',
                    dataType: 'json',
                    success: (data) => {
                        $('#city').empty();
                        $('#city').append('<option value="">Select City</option>');
                        let city = data.map(x =>
                            `<option value="${x?.id}" ${x?.id==selected?"selected":""}>${x?.name}</option>`);
                        $('#city').append(city);
                    }
                });
            } else {
                $('#city').empty();
                $('#city').append('<option value="">Select City</option>');
            }
        }

        function checkAddress() {
            let cityId = $('#city').val();
            let street_address = $("#street_address").val();
            let zip_code = $("#zip_code").val();
            let phone = $("#phone").val();
            if (phone.length != 12) {
                clearQuotes();
                $("#submitMessage").text("Please fill up all required fields with correct information!");
            } else if (cityId && street_address && zip_code && phone) {
                $("#submitMessage").text("");
                let country = $('#country').children(':selected').text();
                let state = $('#state').children(':selected').text();
                let city = $('#city').children(':selected').text();
                $('#id').children(':selected').text();
                GetShippingCost(phone, country, state, city, zip_code, street_address);
            } else {
                $("#submitMessage").text("Please fill up all required fields with correct information!");
                $("#submitBtn").attr("disabled", true);
            }
        }

        function GetShippingCost(phone, country, state, city, zip_code, street_address) {
            $("#loader").html(`Loading...`);
            $("#shippingCost").hide();
            $.ajax({
                url: "/deliveries/quotes",
                type: 'POST',
                dataType: 'json',
                data: {
                    _token: "{{ csrf_token() }}",
                    phone,
                    country,
                    city,
                    state,
                    zip_code,
                    street_address
                },
                success: (data) => {
                    console.log('data',data)
                    $("#shippingCost").show();
                    $("#loader").html(``);
                    if (data?.id) {
                        let fee = parseFloat(data?.fee) / 100;
                        $('#shippingCost').text(`$${fee.toFixed(2)}`);
                        $('#delivery_fee').val(fee.toFixed(2));
                        let totalPrice = parseFloat(fee) + parseFloat({{ Helper::totalCartPrice() }});
                        $('#order_total_price span').text(`$${totalPrice.toFixed(2)}`);
                        $("#quotesId").val(data?.id)
                        $("#submitMessage").text("");
                        $("#submitBtn").removeAttr("disabled");
                    } else {
                        clearQuotes();
                        $("#submitMessage").text("Unable to Deliver in this area! Please type appropriate address.");
                        $("#submitBtn").attr("disabled", true);
                    }
                }
            })
        }

        function clearQuotes() {
            let fee = 0;
            $('#shippingCost').text(`$${fee.toFixed(2)}`);
            $('#delivery_fee').val(fee.toFixed(2));
            let totalPrice = parseFloat(fee) + parseFloat({{ Helper::totalCartPrice() }});
            $('#order_total_price span').text(`$${totalPrice.toFixed(2)}`);
            $("#quotesId").val("");
            $("#submitBtn").attr("disabled", true);
        }
    </script>
@endpush
