@extends('user.layouts.master')

@section('title','Admin Profile')

@section('main-content')

<div class="card shadow mb-4">
    <div class="row">
        <div class="col-md-12">
           @include('backend.layouts.notification')
        </div>
    </div>
   <div class="card-header py-3">
     <h4 class=" font-weight-bold">Profile</h4>
     <ul class="breadcrumbs">
         <li><a href="{{route('admin')}}" style="color:#999">Dashboard</a></li>
         <li><a href="" class="active text-primary">Profile Page</a></li>
     </ul>
   </div>
   <div class="card-body">
        <div class="row">
            <div class="col-md-4">
                <div class="card">
                    <div class="image">
                        @if($profile->photo)
                        <img class="card-img-top img-fluid roundend-circle mt-4" style="border-radius:50%;height:80px;width:80px;margin:auto;" src="{{$profile->photo}}" alt="profile picture">
                        @else 
                        <img class="card-img-top img-fluid roundend-circle mt-4" style="border-radius:50%;height:80px;width:80px;margin:auto;" src="{{asset('backend/img/avatar.png')}}" alt="profile picture">
                        @endif
                    </div>
                    <div class="card-body mt-4 ml-2">
                      <h5 class="card-title text-left"><small><i class="fas fa-user"></i> {{$profile->name}}</small></h5>
                      <p class="card-text text-left"><small><i class="fas fa-envelope"></i> {{$profile->email}}</small></p>
                      <p class="card-text text-left"><small class="text-muted"><i class="fas fa-hammer"></i> {{$profile->role}}</small></p>
                    </div>
                  </div>
            </div>
            <div class="col-md-8">
                <form class="border px-4 pt-2 pb-3" method="POST" action="{{route('user-profile-update',$profile->id)}}">
                    @csrf
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="inputTitle" class="col-form-label">Name</label>
                                <input id="inputTitle" type="text" name="name" placeholder="Enter name"  value="{{$profile->name}}" class="form-control">
                                @error('name')
                                <span class="text-danger">{{$message}}</span>
                                @enderror
                              </div>
                              <div class="form-group">
                                <label for="inputEmail" class="col-form-label">Email</label>
                              <input id="inputEmail" disabled type="email" name="email" placeholder="Enter email"  value="{{$profile->email}}" class="form-control">
                              @error('email')
                              <span class="text-danger">{{$message}}</span>
                              @enderror
                            </div>
                            <div class="form-group">
                                <label for="phone" class="col-form-label">Phone</label>
                                <input id="phone" type="text" name="phone" placeholder="Enter Contact Number"  value="{{$profile->phone}}" class="form-control">
                                @error('phone')
                                <span class="text-danger">{{$message}}</span>
                                @enderror
                            </div>
                            <div class="form-group">
                                <label for="inputPhoto" class="col-form-label">Photo</label>
                                <div class="input-group">
                                    <span class="input-group-btn">
                                        <a id="lfm" data-input="thumbnail" data-preview="holder" class="btn btn-primary">
                                        <i class="fa fa-picture-o"></i> Choose
                                        </a>
                                    </span>
                                    <input id="thumbnail" class="form-control" type="text" name="photo" value="{{$profile->photo}}">
                                </div>
                                @error('photo')
                                <span class="text-danger">{{$message}}</span>
                                @enderror
                              </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="country" class="col-form-label">Countries</label>
                                <select id="country" name="country" class="form-control" required>
                                  <option value="">Select Country</option>
                                    @foreach($Countries as $country)
                                        <option value="{{ $country->id }}" @selected($country->id==$profile->country)>{{ $country->name }}</option>
                                    @endforeach
                                </select>
                              @error('country')
                              <span class="text-danger">{{$message}}</span>
                              @enderror
                            </div>
                            <div class="form-group">
                                <label for="state" class="col-form-label">State</label>
                                <select id="state" name="state" class="form-control" required>
                                    @foreach($States as $State)
                                        <option value="{{ $State->id }}" @selected($State->id==$profile->state)>{{ $State->name }}</option>
                                    @endforeach
                                </select>
                              @error('state')
                              <span class="text-danger">{{$message}}</span>
                              @enderror
                            </div>
                            <div class="form-group">
                                <label for="city" class="col-form-label">City</label>
                                <select id="city" name="city" class="form-control" required>
                                    @foreach($Cities as $city)
                                        <option value="{{ $city->id }}" @selected($city->id==$profile->city)>{{ $city->name }}</option>
                                    @endforeach
                                </select>
                              @error('City')
                              <span class="text-danger">{{$message}}</span>
                              @enderror
                            </div>
                            <div class="form-group">
                                <label for="zip_code"  class="col-form-label">Zip Code</label>
                                <input type="text" id="zip_code" name="zip_code" class="form-control" placeholder="" value="{{$profile->zip_code}}" required>
                                @error('zip_code')
                                    <span class='text-danger'>{{$message}}</span>
                                @enderror
                            </div>
                            <div class="form-group">
                                <label for="street_address" class="col-form-label">Street Address</label>
                                <textarea id="street_address" name="street_address" class="form-control" placeholder="House No, Road No, Block, City, State" required>{{$profile->street_address}}</textarea>
                                @error('street_address')
                                <span class="text-danger">{{ $message }}</span>
                                @enderror
                            </div>
                        </div>
                    </div>
                    <div class="col-sm-12 text-center">
                        <button type="submit" class="btn btn-success btn-sm">Update</button>
                    </div>
                </form>
            </div>
        </div>
   </div>
</div>

@endsection

<style>
    .breadcrumbs{
        list-style: none;
    }
    .breadcrumbs li{
        float:left;
        margin-right:10px;
    }
    .breadcrumbs li a:hover{
        text-decoration: none;
    }
    .breadcrumbs li .active{
        color:red;
    }
    .breadcrumbs li+li:before{
      content:"/\00a0";
    }
    .image{
        background:url('{{asset('backend/img/background.jpg')}}');
        height:150px;
        background-position:center;
        background-attachment:cover;
        position: relative;
    }
    .image img{
        position: absolute;
        top:55%;
        left:35%;
        margin-top:30%;
    }
    i{
        font-size: 14px;
        padding-right:8px;
    }
  </style> 

@push('scripts')
<script src="/vendor/laravel-filemanager/js/stand-alone-button.js"></script>
<script>
    $('#lfm').filemanager('image');
    $(document).ready(function(){
        $('#country').change(function(){
            $('#city').empty();
            $("#street_address").val("");
            $("#zip_code").val("");
            GetStates($(this).val());
        });

        $('#state').change(function() {
            $("#street_address").val("");
            $("#zip_code").val("");
            GetCity($(this).val());
        });
        $("#city").change(function(){
            $("#street_address").val("");
            $("#zip_code").val("");
        })
    })
    function GetStates(countryId,selected=null){
        if (countryId) {
            
            $.ajax({
                url: `/countries/${countryId}/states`,
                type: 'GET',
                dataType: 'json',
                success: (data)=> {
                    $('#state').empty().append('<option value="">Select State</option>');
                    let states=data.map(x=>`<option value="${x?.id}" ${x?.id==selected?"selected":""}>${x?.name}</option>`);
                    $('#state').append(states); 
                }
            });
        } else {
            $('#state').empty();
            $('#state').append('<option value="">Select State</option>');
        }
    }
    function GetCity(stateId,selected=null){
        if (stateId) {
              $.ajax({
                  url: `/states/${stateId}/cities`,
                  type: 'GET',
                  dataType: 'json',
                  success: (data)=> {
                      $('#city').empty();
                      $('#city').append('<option value="">Select City</option>');
                      let city=data.map(x=>`<option value="${x?.id}" ${x?.id==selected?"selected":""}>${x?.name}</option>`);
                      $('#city').append(city);
                }
              });
          } else {
              $('#city').empty();
              $('#city').append('<option value="">Select City</option>');
          }
    }
</script>
@endpush